package com.ruoyi.mall.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.mall.mapper.MallSchoolMasterRecordMapper;
import com.ruoyi.mall.domain.MallSchoolMasterRecord;
import com.ruoyi.mall.service.IMallSchoolMasterRecordService;

/**
 * 学校保研记录Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-10-26
 */
@Service
public class MallSchoolMasterRecordServiceImpl implements IMallSchoolMasterRecordService 
{
    @Autowired
    private MallSchoolMasterRecordMapper mallSchoolMasterRecordMapper;

    /**
     * 查询学校保研记录
     * 
     * @param masterRecordId 学校保研记录主键
     * @return 学校保研记录
     */
    @Override
    public MallSchoolMasterRecord selectMallSchoolMasterRecordByMasterRecordId(Long masterRecordId)
    {
        return mallSchoolMasterRecordMapper.selectMallSchoolMasterRecordByMasterRecordId(masterRecordId);
    }

    /**
     * 查询学校保研记录列表
     * 
     * @param mallSchoolMasterRecord 学校保研记录
     * @return 学校保研记录
     */
    @Override
    public List<MallSchoolMasterRecord> selectMallSchoolMasterRecordList(MallSchoolMasterRecord mallSchoolMasterRecord)
    {
        return mallSchoolMasterRecordMapper.selectMallSchoolMasterRecordList(mallSchoolMasterRecord);
    }

    /**
     * 新增学校保研记录
     * 
     * @param mallSchoolMasterRecord 学校保研记录
     * @return 结果
     */
    @Override
    public int insertMallSchoolMasterRecord(MallSchoolMasterRecord mallSchoolMasterRecord)
    {
        return mallSchoolMasterRecordMapper.insertMallSchoolMasterRecord(mallSchoolMasterRecord);
    }

    /**
     * 修改学校保研记录
     * 
     * @param mallSchoolMasterRecord 学校保研记录
     * @return 结果
     */
    @Override
    public int updateMallSchoolMasterRecord(MallSchoolMasterRecord mallSchoolMasterRecord)
    {
        return mallSchoolMasterRecordMapper.updateMallSchoolMasterRecord(mallSchoolMasterRecord);
    }

    /**
     * 批量删除学校保研记录
     * 
     * @param masterRecordIds 需要删除的学校保研记录主键
     * @return 结果
     */
    @Override
    public int deleteMallSchoolMasterRecordByMasterRecordIds(Long[] masterRecordIds)
    {
        return mallSchoolMasterRecordMapper.deleteMallSchoolMasterRecordByMasterRecordIds(masterRecordIds);
    }

    /**
     * 删除学校保研记录信息
     * 
     * @param masterRecordId 学校保研记录主键
     * @return 结果
     */
    @Override
    public int deleteMallSchoolMasterRecordByMasterRecordId(Long masterRecordId)
    {
        return mallSchoolMasterRecordMapper.deleteMallSchoolMasterRecordByMasterRecordId(masterRecordId);
    }
}
